@@ -1,6 +1,5 @@
 #' @import magrittr forestmodel
 cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Hazard ratio", ci = NULL, p = "p")) {
-
   panels <- list(
     forest_panel(width = 0.03),
     forest_panel(width = 0.1, display = variable, fontface = "bold", heading = headings$variable),
@@ -14,14 +13,15 @@ cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Ha
     forest_panel(width = 0.03, item = "vline", hjust = 0.5),
     forest_panel(
       width = 0.12,
-      display = dplyr::if_else(reference, "Reference",
-                        sprintf("%0.2f (%0.2f, %0.2f)", trans(estimate), trans(conf.low), trans(conf.high))
+      display = dplyr::if_else(reference, dplyr::if_else(!is.numeric(p.value), "Reference", "Reference;  Variable logrank:"),
+        sprintf("%0.2f (%0.2f, %0.2f)", trans(estimate), trans(conf.low), trans(conf.high))
       ),
       heading = headings$ci,
       display_na = NA
     ),
     forest_panel(
-      width = 0.05, display = dplyr::if_else(reference, "", format.pval(p.value, digits = 1, eps = 1e-3)), display_na = NA,
+      width = 0.05,
+      display = dplyr::if_else(reference & !is.numeric(p.value), "", format.pval(p.value, digits = 1, eps = 1e-3)), display_na = NA,
       hjust = 1, heading = headings$p
     ),
     forest_panel(width = 0.03)
@@ -31,6 +31,8 @@ cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Ha
 }
 
 utils::globalVariables(
-  c("variable", "level", "n", "reference", "estimate", "conf.low", "conf.high", "p.value", "trans",
-    "forest_panel")
+  c(
+    "variable", "level", "n", "reference", "estimate", "conf.low", "conf.high", "p.value", "trans",
+    "forest_panel"
+  )
 )
